##
##  rqlite.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_rqlite_base 7.0.0
%define       V_rqlite_snap 20220129

#   package information
Name:         rqlite
Summary:      Replicated SQLite Database
URL:          https://github.com/otoolep/rqlite
Vendor:       Philip O'Toole
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MIT
Version:      %{V_rqlite_base}.%{V_rqlite_snap}
Release:      20220129

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/rqlite/rqlite-%{V_rqlite_snap}.tar.xz
Source1:      rc.rqlite

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    RQlite is a distributed system that provides a replicated SQLite
    database. RQlite is written in Go and uses RAFT to achieve consensus
    across all the instances of the SQLite databases. rqlite ensures
    that every change made to the database is made to a quorum of SQLite
    files, or none at all. RQlite gives you the functionality of a
    fault-tolerant, replicated relational database, but with very easy
    installation, deployment, and operation. Read/Writes are always
    through the master node, because RQLite is about fault-tolerance,
    not performance.

%track
    prog rqlite:release = {
        version   = %{V_rqlite_base}
        url       = https://github.com/otoolep/rqlite/releases
        regex     = v(__VER__)\.tar\.gz
    }
    prog rqlite:snapshot = {
        version   = %{V_rqlite_snap}
        url       = http://download.openpkg.org/components/versioned/rqlite/
        regex     = rqlite-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n rqlite

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/rqlite/rqlite
    ( cd cmd/rqlite  && go build -v . ) || exit $?
    ( cd cmd/rqlited && go build -v . ) || exit $?

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rqlite \
        $RPM_BUILD_ROOT%{l_prefix}/var/rqlite/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/rqlite/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/rqlite/db

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/rqlite/rqlite/cmd/rqlite/rqlite \
        $RPM_BUILD_ROOT%{l_prefix}/bin/rqlite
    %{l_shtool} install -c -s -m 755 \
        src/github.com/rqlite/rqlite/cmd/rqlited/rqlited \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/rqlited

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.rqlite} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/rqlite/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/etc/rqlite' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/rqlite/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} rqlite status 2>/dev/null`
        [ ".$rqlite_active" = .yes ] && %{l_rc} rqlite restart
    fi
    exit 0

%preun
    #   before erase, stop service and remove log files
    if [ $1 -eq 0 ]; then
        %{l_rc} rqlite stop 2>/dev/null
        rm -f  $RPM_INSTALL_PREFIX/var/rqlite/log/* >/dev/null 2>&1 || true
        rm -f  $RPM_INSTALL_PREFIX/var/rqlite/run/* >/dev/null 2>&1 || true
        rm -rf $RPM_INSTALL_PREFIX/var/rqlite/db/*  >/dev/null 2>&1 || true
    fi
    exit 0

